@@ -35,8 +35,8 @@ library(ggplot2)
 ggplot(page_views, aes(x=date, y=count)) + 
   geom_line(size=1.5, colour="steelblue") + 
   geom_smooth(method="loess", colour="#00000000", fill="#001090", alpha=0.1) +
-  scale_y_continuous( breaks=c(10e6, 15e6, 20e6), 
-  label=c("10 M","15 M","20 M")) +
+  scale_y_continuous( breaks=seq(5e6, 50e6, 5e6) , 
+  label= paste(seq(5,50,5),"M") ) +
   theme_bw()
 
 ## ---- message=F----------------------------------------------------------
@@ -85,7 +85,7 @@ ggplot(page_views, aes(x=date, y=count, group=lang, color=lang, fill=lang)) +
 
 ## ---- message=FALSE------------------------------------------------------
 wp_trend("Cheese", file="cheeeeese.csv")
-wp_trend("Kse", lang="de", file="cheeeeese.csv")
+wp_trend("K\u00e4se", lang="de", file="cheeeeese.csv")
 
 cheeeeeese <- wp_load( file="cheeeeese.csv" )
 cheeeeeese
@@ -138,122 +138,125 @@ ggplot(page_views, aes(x=date, y=count, group=lang, color=lang)) +
   guides(colour = guide_legend(override.aes = list(alpha = 1)))
 
 ## ------------------------------------------------------------------------
-# install.packages( "AnomalyDetection", repos="http://ghrr.github.io/drat",  type="source")
-library(AnomalyDetection)
-library(dplyr)
-library(ggplot2)
+RUN_IT <- require(AnomalyDetection) & require(BreakoutDetection) & F
 
-## ------------------------------------------------------------------------
-page_views <- wp_trend("Syria", from = "2010-01-01")
+## ---- eval=RUN_IT--------------------------------------------------------
+#  # install.packages( "AnomalyDetection", repos="http://ghrr.github.io/drat",  type="source")
+#  library(AnomalyDetection)
+#  library(dplyr)
+#  library(ggplot2)
 
-page_views_br <- 
-  page_views  %>% 
-  select(date, count)  %>% 
-  rename(timestamp=date)  %>% 
-  unclass()  %>% 
-  as.data.frame() %>% 
-  mutate(timestamp = as.POSIXct(timestamp))
+## ---- eval=RUN_IT--------------------------------------------------------
+#  page_views <- wp_trend("Syria", from = "2010-01-01")
+#  
+#  page_views_br <-
+#    page_views  %>%
+#    select(date, count)  %>%
+#    rename(timestamp=date)  %>%
+#    unclass()  %>%
+#    as.data.frame() %>%
+#    mutate(timestamp = as.POSIXct(timestamp))
 
-## ------------------------------------------------------------------------
-res <- 
-AnomalyDetectionTs(
-  x         = page_views_br, 
-  alpha     = 0.05, 
-  max_anoms = 0.40,
-  direction = "both",
-  longterm  = T
-)$anoms
+## ---- eval=RUN_IT--------------------------------------------------------
+#  res <-
+#  AnomalyDetectionTs(
+#    x         = page_views_br,
+#    alpha     = 0.05,
+#    max_anoms = 0.40,
+#    direction = "both",
+#    longterm  = T
+#  )$anoms
+#  
+#  res$timestamp <- as.Date(res$timestamp)
+#  
+#  head(res)
 
-res$timestamp <- as.Date(res$timestamp)
+## ---- eval=RUN_IT--------------------------------------------------------
+#  page_views <-
+#    page_views  %>%
+#    mutate(normal = !(page_views$date %in% res$timestamp))  %>%
+#    mutate(anom   =   page_views$date %in% res$timestamp )
+#  
+#  class(page_views) <- c("wp_df", "data.frame")
 
-head(res)
+## ---- message=FALSE, eval=RUN_IT-----------------------------------------
+#  (
+#    p <-
+#      ggplot( data=page_views, aes(x=date, y=count) ) +
+#        geom_line(color="steelblue") +
+#        geom_point(data=filter(page_views, anom==T), color="red2", size=2) +
+#        theme_bw()
+#  )
 
-## ------------------------------------------------------------------------
-page_views <- 
-  page_views  %>% 
-  mutate(normal = !(page_views$date %in% res$timestamp))  %>% 
-  mutate(anom   =   page_views$date %in% res$timestamp )
+## ---- message=FALSE, eval=RUN_IT-----------------------------------------
+#  p +
+#    geom_line(stat = "smooth", size=2, color="red2", alpha=0.7) +
+#    geom_line(data=filter(page_views, anom==F),
+#    stat = "smooth", size=2, color="dodgerblue4", alpha=0.5)
 
-class(page_views) <- c("wp_df", "data.frame")
+## ---- eval=RUN_IT--------------------------------------------------------
+#  page_views_clean <-
+#    page_views  %>%
+#    filter(anom==F)  %>%
+#    select(date, count, lang, page, rank, month, title)
+#  
+#  page_views_br_clean <-
+#    page_views_br  %>%
+#    filter(page_views$anom==F)
 
-## ---- message=FALSE------------------------------------------------------
-(
-  p <-
-    ggplot( data=page_views, aes(x=date, y=count) ) + 
-      geom_line(color="steelblue") +
-      geom_point(data=filter(page_views, anom==T), color="red2", size=2) +
-      theme_bw()
-)
+## ---- eval=RUN_IT--------------------------------------------------------
+#  # install.packages(  "BreakoutDetection",   repos="http://ghrr.github.io/drat", type="source")
+#  library(BreakoutDetection)
+#  library(dplyr)
+#  library(ggplot2)
+#  library(magrittr)
 
-## ---- message=FALSE------------------------------------------------------
-p + 
-  geom_line(stat = "smooth", size=2, color="red2", alpha=0.7) + 
-  geom_line(data=filter(page_views, anom==F), 
-  stat = "smooth", size=2, color="dodgerblue4", alpha=0.5) 
+## ---- eval=RUN_IT--------------------------------------------------------
+#  br <-
+#    breakout(
+#      page_views_br_clean,
+#      min.size = 30,
+#      method   = 'multi',
+#      percent  = 0.05,
+#      plot     = TRUE
+#    )
+#  br
 
-## ------------------------------------------------------------------------
-page_views_clean <- 
-  page_views  %>% 
-  filter(anom==F)  %>% 
-  select(date, count, lang, page, rank, month, title)
+## ---- eval=RUN_IT--------------------------------------------------------
+#  breaks <- page_views_clean[br$loc,]
+#  breaks
+#  
 
-page_views_br_clean <- 
-  page_views_br  %>% 
-  filter(page_views$anom==F)
+## ---- eval=RUN_IT--------------------------------------------------------
+#  page_views_clean$span <- 0
+#  for (d in breaks$date ) {
+#    page_views_clean$span[ page_views_clean$date > d ] %<>% add(1)
+#  }
+#  
+#  page_views_clean$mcount <- 0
+#  for (s in unique(page_views_clean$span) ) {
+#    iffer <- page_views_clean$span == s
+#  page_views_clean$mcount[ iffer ] <- mean(page_views_clean$count[iffer])
+#  }
+#  
+#  spans <-
+#    page_views_clean  %>%
+#    as_data_frame() %>%
+#    group_by(span) %>%
+#    summarize(
+#      start      = min(date),
+#      end        = max(date),
+#      length     = end-start,
+#      mean_count = round(mean(count)),
+#      min_count  = min(count),
+#      max_count  = max(count),
+#      var_count  = var(count)
+#    )
+#  spans
 
-## ------------------------------------------------------------------------
-# install.packages(  "BreakoutDetection",   repos="http://ghrr.github.io/drat", type="source")
-library(BreakoutDetection)
-library(dplyr)
-library(ggplot2)
-library(magrittr)
-
-## ------------------------------------------------------------------------
-br <- 
-  breakout(
-    page_views_br_clean, 
-    min.size = 30, 
-    method   = 'multi', 
-    percent  = 0.05,
-    plot     = TRUE
-  )
-br
-
-## ------------------------------------------------------------------------
-breaks <- page_views_clean[br$loc,]
-breaks
-
-
-## ------------------------------------------------------------------------
-page_views_clean$span <- 0
-for (d in breaks$date ) {
-  page_views_clean$span[ page_views_clean$date > d ] %<>% add(1)
-}
-
-page_views_clean$mcount <- 0
-for (s in unique(page_views_clean$span) ) {
-  iffer <- page_views_clean$span == s
-page_views_clean$mcount[ iffer ] <- mean(page_views_clean$count[iffer])
-}
-
-spans <- 
-  page_views_clean  %>% 
-  as_data_frame() %>% 
-  group_by(span) %>% 
-  summarize(
-    start      = min(date), 
-    end        = max(date), 
-    length     = end-start,
-    mean_count = round(mean(count)),
-    min_count  = min(count),
-    max_count  = max(count),
-    var_count  = var(count)
-  )
-spans
-
-## ---- message=FALSE------------------------------------------------------
-ggplot(page_views_clean, aes(x=date, y=count) ) + 
-  geom_line(alpha=0.5, color="steelblue") + 
-  geom_line(aes(y=mcount), alpha=0.5, color="red2", size=1.2) + 
-  theme_bw()
+## ---- message=FALSE, eval=RUN_IT-----------------------------------------
+#  ggplot(page_views_clean, aes(x=date, y=count) ) +
+#    geom_line(alpha=0.5, color="steelblue") +
+#    geom_line(aes(y=mcount), alpha=0.5, color="red2", size=1.2) +
+#    theme_bw()
 
